@@ -1,4 +1,6 @@
-# Copyright (C) 2012-2020 Etienne Millon <me@emillon.org>
+# Copyright (C) 2012-2022 Amir Yalon <git@please.nospammail.net>
+#                         Etienne Millon <me@emillon.org>
+#                         Faye Duxovni <duxovni@duxovni.org>
 #                         Gregory Soutade <gregory@soutade.fr>
 #                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Karthikeyan Singaravelan <tir.karthi@gmail.com>
@@ -6,7 +8,9 @@
 #                         Martin Monperrus <monperrus@users.noreply.github.com>
 #                         Nicolas KAROLAK <nicolas@karolak.fr>
 #                         Profpatsch <mail@profpatsch.de>
+#                         Timendum <timedum@gmail.com>
 #                         W. Trevor King <wking@tremily.us>
+#                         auouymous <au@qzx.com>
 #
 # This file is part of rss2email.
 #
@@ -43,7 +47,7 @@ def new(feeds, args):
         feeds.config['DEFAULT']['to'] = args.email
     if _os.path.exists(feeds.configfiles[-1]):
         raise _error.ConfigAlreadyExistsError(feeds=feeds)
-    feeds.save()
+    feeds.save_config()
 
 def email(feeds, args):
     "Update the default target email address"
@@ -52,7 +56,7 @@ def email(feeds, args):
     else:
         _LOG.info('set the default target email to {}'.format(args.email))
     feeds.config['DEFAULT']['to'] = args.email
-    feeds.save()
+    feeds.save_config()
 
 def add(feeds, args):
     "Add a new feed to the database"
@@ -60,7 +64,10 @@ def add(feeds, args):
     _LOG.info('add new feed {}'.format(feed))
     if not feed.to:
         raise _error.NoToEmailAddress(feed=feed, feeds=feeds)
-    feeds.save()
+    if args.only_new:
+        feed.run(send=False, clean=False)
+    feeds.save_config()
+    feeds.save_feeds()
 
 def run(feeds, args):
     "Fetch feeds and send entry emails."
@@ -87,12 +94,12 @@ def run(feeds, args):
                             interval = interval
                         ))
                         _time.sleep(interval)
-                    feed.run(send=args.send)
+                    feed.run(send=args.send, clean=args.clean)
                 except _error.RSS2EmailError as e:
                     e.log()
                 last_server = current_server
     finally:
-        feeds.save()
+        feeds.save_feeds()
 
 def list(feeds, args):
     "List all the feeds in the database"
@@ -115,7 +122,7 @@ def _set_active(feeds, args, active=True):
         feed = feeds.index(index)
         _LOG.info('{} feed {}'.format(action, feed))
         feed.active = active
-    feeds.save()
+    feeds.save_config()
 
 def pause(feeds, args):
     "Pause a feed (disable fetching)"
@@ -134,7 +141,8 @@ def delete(feeds, args):
     for feed in to_remove:
         _LOG.info('deleting feed {}'.format(feed))
         feeds.remove(feed)
-    feeds.save()
+    feeds.save_config()
+    feeds.save_feeds()
 
 def reset(feeds, args):
     "Forget dynamic feed data (e.g. to re-send old entries)"
@@ -144,7 +152,7 @@ def reset(feeds, args):
         feed = feeds.index(index)
         _LOG.info('resetting feed {}'.format(feed))
         feed.reset()
-    feeds.save()
+    feeds.save_feeds()
 
 def opmlimport(feeds, args):
     "Import configuration from OPML."
@@ -172,7 +180,8 @@ def opmlimport(feeds, args):
                     name = name_slug_regexp.sub('-', text)
             feed = feeds.new_feed(name=name, url=url)
             _LOG.info('add new feed {}'.format(feed))
-    feeds.save()
+    feeds.save_config()
+    feeds.save_feeds()
 
 def opmlexport(feeds, args):
     "Export configuration to OPML."
