@@ -1,16 +1,20 @@
-# Copyright (C) 2004-2020 Aaron Swartz
+# Copyright (C) 2004-2022 Aaron Swartz
+#                         Alyssa Ross <hi@alyssa.is>
+#                         Amir Yalon <git@please.nospammail.net>
 #                         Anders Damsgaard <anders@adamsgaard.dk>
 #                         Andrey Zelenchuk <azelenchuk@parallels.com>
 #                         Andrey Zelenchuk <azelenchuk@plesk.com>
 #                         Brian Lalor
 #                         Dean Jackson
 #                         Dmitry Bogatov <KAction@gnu.org>
+#                         Ellen Wang <squeakbat@users.noreply.github.com>
 #                         Erik Hetzner
 #                         Etienne Millon <me@emillon.org>
 #                         François Boulogne <fboulogne sciunto org>
 #                         George Saunders <georgesaunders@gmail.com>
 #                         Jakub Wilk <jwilk@jwilk.net>
 #                         Joey Hess
+#                         Josh Wainwright <git@jawainwright.co.uk>
 #                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Lindsey Smith <lindsey.smith@gmail.com>
 #                         Léo Gaspard <leo@gaspard.io>
@@ -24,6 +28,8 @@
 #                         W. Trevor King <wking@tremily.us>
 #                         Yannik Sembritzki <yannik@sembritzki.me>
 #                         auouymous <au@qzx.com>
+#                         boyska <piuttosto@logorroici.org>
+#                         ryneeverett <ryneeverett@gmail.com>
 #
 # This file is part of rss2email.
 #
@@ -49,7 +55,7 @@ import html2text as _html2text
 
 class Config (_configparser.ConfigParser):
     def __init__(self, dict_type=_collections.OrderedDict,
-                 interpolation=_configparser.ExtendedInterpolation(),
+                 interpolation=None,
                  **kwargs):
         super(Config, self).__init__(
             dict_type=dict_type, interpolation=interpolation, **kwargs)
@@ -66,6 +72,10 @@ class Config (_configparser.ConfigParser):
             section, 'unicode-snob')
         _html2text.config.LINKS_EACH_PARAGRAPH = self.getboolean(
             section, 'links-after-each-paragraph')
+        _html2text.config.INLINE_LINKS = self.getboolean(
+            section, 'inline-links')
+        _html2text.config.WRAP_LINKS = self.getboolean(
+            section, 'wrap-links')
         # hack to prevent breaking the default in every existing config file
         body_width = self.getint(section, 'body-width')
         _html2text.config.BODY_WIDTH = 0 if body_width < 0 else 78 if body_width == 0 else body_width
@@ -83,11 +93,11 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # Transfer-Encoding. For local mailing it is safe and
         # convenient to use 8bit.
         ('use-8bit', str(False)),
-        # True: Only use the 'from' address.
+        # True: Only use the 'from' address. Overrides the use-publisher-email setting.
         # False: Use the email address specified by the feed, when possible.
         ('force-from', str(False)),
-        # True: Use the publisher's email if you can't find the author's.
-        # False: Just use the 'from' email instead.
+        # True: Use author's email if found, or use publisher's email if found, or use the 'from' setting.
+        # False: Use author's email if found, or use the 'from' setting.
         ('use-publisher-email', str(False)),
         # If empty, only use the feed email address rather than
         # friendly name plus email address.  Available attributes may
@@ -112,6 +122,9 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # True: Send a single, multi-entry email per feed per rss2email run.
         # False: Send a single email per entry.
         ('digest', str(False)),
+        # multipart/digest: use Content-type: multipart/digest
+        # multipart/mixed: use Content-type: multipart/mixed
+        ('digest-type', 'multipart/digest'),
         # True: Generate Date header based on item's date, when possible.
         # False: Generate Date header based on time sent.
         ('date-header', str(False)),
@@ -132,7 +145,7 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # because the old entries will not be recorded under their new
         # link-based ids.
         ('trust-link', str(False)),
-        # If 'trust-guid' or 'trust-link' is True, this settings allows to receive
+        # If 'trust-guid' or 'trust-link' is True, this setting allows to receive
         # a new email message in reply to the previous one when the post changes.
         ('reply-changes', str(False)),
         # To most correctly encode emails with international
@@ -148,10 +161,15 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # digest message before it is mailed.
         # Example: digest-post-process = 'rss2email.post_process.downcase downcase_message'
         ('digest-post-process', ''),
+        # The format for the Subject line.  Available attributes are
+        # 'feed', 'feed-name', 'feed-url', 'feed-title'.
+        ('subject-format', '{feed-title}'),
+
         ## HTML conversion
         # True: Send text/html messages when possible.
         # False: Convert HTML to plain text.
         ('html-mail', str(False)),
+        ('multipart-html', str(False)),
         # Optional CSS styling
         ('use-css', str(False)),
         ('css', (
@@ -186,10 +204,10 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
                 '  padding: 5px;\n'
                 '  margin-bottom: 0px;\n'
                 '}\n'
-                '#entry {\n'
+                '.entry {\n'
                 '  border: solid 4px #c3d9ff;\n'
                 '}\n'
-                '#body {\n'
+                '.body {\n'
                 '  margin-left: 5px;\n'
                 '  margin-right: 5px;\n'
                 '}\n')),
@@ -198,6 +216,10 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ('unicode-snob', str(False)),
         # Put the links after each paragraph instead of at the end.
         ('links-after-each-paragraph', str(False)),
+        # Use inline, rather than reference, for formatting images and links.
+        ('inline-links', str(True)),
+        # Wrap links according to body width.
+        ('wrap-links', str(True)),
         # Wrap long lines at position.
         # Any negative value for no wrapping, 0 for 78 width (compatibility), or any positive width.
         ('body-width', str(0)),
@@ -208,6 +230,7 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # True: Use SMTP_SERVER to send mail.
         # Sendmail (or compatible) configuration
         ('sendmail', '/usr/sbin/sendmail'),  # Path to sendmail (or compatible)
+        ('sendmail_config', ''),
         # SMTP configuration
         ('smtp-auth', str(False)),      # set to True to use SMTP AUTH
         ('smtp-username', 'username'),  # username for SMTP AUTH
